pub struct NextRef<'w, 's, S: State> { /* private fields */ }Expand description
A SystemParam with read-only access to the next value of the State type S.
NOTE: The next state is only set in stone during the StateFlush
schedule after ResolveStateSystems::<S>::Compute.
Example
fn spawn_new_menu(menu: NextRef<Menu>) {
match menu.unwrap() {
Menu::Main => spawn_main_menu(),
Menu::Settings => spawn_settings_menu(),
}
}Implementations
Sourceimpl<S: State> NextRef<'_, '_, S>
impl<S: State> NextRef<'_, '_, S>
Sourcepub fn get(&self) -> Option<&S>
pub fn get(&self) -> Option<&S>
Get a read-only reference to the next state, or None if disabled.
Sourcepub fn will_be_disabled(&self) -> bool
pub fn will_be_disabled(&self) -> bool
Check if the next state will be disabled.
Sourcepub fn will_be_enabled(&self) -> bool
pub fn will_be_enabled(&self) -> bool
Check if the next state will be enabled.
Sourcepub fn will_be_in<P: StatePattern<S>>(&self, pattern: &P) -> bool
pub fn will_be_in<P: StatePattern<S>>(&self, pattern: &P) -> bool
Check if the next state will be enabled and match a specific StatePattern.
Sourcepub fn is_triggered(&self) -> bool
pub fn is_triggered(&self) -> bool
Check if S is triggered to flush in the
StateFlush schedule.